<?xml version="1.0"?>
<xsl:stylesheet 
version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="/hdpq">
    <HTML>
      <HEAD>
        <TITLE></TITLE>
      </HEAD>
      <BODY>
        <xsl:apply-templates select="hdpq-report"/>
        <xsl:apply-templates select="hdpq-setup"/>
        <xsl:apply-templates select="hdpq-status"/>
      </BODY>
    </HTML>
  </xsl:template>
  
  <xsl:template match="hdpq-report">
        <H1><center><xsl:apply-templates select="report-name"/></center></H1>
        
        <H2>Introduction</H2>
        <p><xsl:apply-templates select="report-intro"/></p>

        <xsl:apply-templates select="instrument"/>
        <xsl:apply-templates select="monitoring"/>
        <xsl:apply-templates select="events"/>
        <xsl:apply-templates select="config"/>

        <H2>Images</H2>
        <table border="0">
          <xsl:apply-templates select="/hdpq/hdpq-report/images/image"/>
        </table>

        <H2>Conclusion</H2>
        <xsl:apply-templates select="report-conclusion"/>
  </xsl:template>

  <!--
  ===============================================================
                        HDPQ Setup Handling
  ===============================================================
  -->
  
  <xsl:template match="hdpq-setup">
    <H2>Appendix: Instrument Setup</H2>
    <xsl:apply-templates select="line"/>
  </xsl:template>

  <xsl:template match="line">
    <br><xsl:value-of select="."/></br>
  </xsl:template>

  <!--
  <xsl:template match="hdpq-setup">
    <H2>Appendix: Instrument Setup</H2>
    <xsl:apply-templates select="commandresult"/>
  </xsl:template>

  <xsl:include href="HDPQCommand_GetAnalyzerConfig.xsl"/>
  -->

  <!--
  ===============================================================
                     End of HDPQ Setup Handling
  ===============================================================
  -->


  <!--
  ===============================================================
                        HDPQ Status Handling
  ===============================================================
  -->

  <xsl:template match="hdpq-status">
    <H2>Appendix: Instrument Status</H2>
    <xsl:apply-templates select="commandresult"/>
  </xsl:template>

  <xsl:include href="HDPQCommand_GetInstStatus.xsl"/>

  <!--
  ===============================================================
                     End of HDPQ Status Handling
  ===============================================================
  -->



  <xsl:template match="text">
    <DIV>
      <xsl:value-of select="."/>
    </DIV>
  </xsl:template>

  <xsl:template match="file">
    <DIV>
      <xsl:copy-of select="document(.)/text"/>
    </DIV>
  </xsl:template>

  <xsl:template match="report-name">
    <DIV>
      <xsl:apply-templates select="text"/>
      <xsl:apply-templates select="file"/>
    </DIV>
  </xsl:template>

  <xsl:template match="report-intro">
    <DIV>
      <xsl:apply-templates select="text"/>
      <xsl:apply-templates select="file"/>
    </DIV>
  </xsl:template>

  <xsl:template match="instrument">
    <DIV>
      <H2>Instrument Summary</H2>
      <p>
        Model: <xsl:value-of select="model-name"/><br></br>
        Serial Number: <xsl:value-of select="serial-number"/>
      </p>
    </DIV>
  </xsl:template>

  <xsl:template match="monitoring">
    <DIV>
      <H2>Monitoring Summary</H2>
      <p>
        Site Name: <xsl:value-of select="site-name"/><br></br>
        Location: <xsl:value-of select="site-loc"/><br></br>
        Installation Notes: <xsl:value-of select="site-note"/>
      </p>
    </DIV>
  </xsl:template>

  <xsl:template match="events">
    <DIV>
      <p>
        Triggered Events: <xsl:value-of select="triggered"/><br></br>
        Timed Events: <xsl:value-of select="timed"/>
      </p>
    </DIV>
  </xsl:template>

  <xsl:template match="config">
    <DIV>
      <H2>Instrument Configuration</H2>
      <p>
        Wiring: <xsl:value-of select="wiring"/><br></br>
        Nominal Voltage: <xsl:value-of select="nom-voltage"/> Vrms<br></br>
        Nominal Frequency: <xsl:value-of select="nom-frequency"/> Hz.
      </p>
      <p>RMS Thresholds:</p>
      <table border="1">
        <tr>
          <td>Name</td>
          <td>High (Vrms)</td>
          <td>Low (Vrms)</td>
          <td>Very Low (Vrms)</td>
        </tr>
        <xsl:apply-templates select="rms/input"/>
      </table>

    </DIV>
  </xsl:template>

  <xsl:template match="site-name">
    <DIV>
      Sitename:
      <xsl:value-of select="."/>
    </DIV>
  </xsl:template>

  <xsl:template match="site-loc">
    <DIV>
      Site Location:
      <xsl:value-of select="."/>
    </DIV>
  </xsl:template>

  <xsl:template match="site-note">
    <DIV>
      Installation Notes:
      <xsl:value-of select="."/>
    </DIV>
  </xsl:template>

  <xsl:template match="input">
    <tr>
      <td>
        <xsl:value-of select="number" />
      </td>
      <td>
        <xsl:value-of select="hi"/>
      </td>
      <td>
        <xsl:value-of select="lo"/>
      </td>
      <td>
        <xsl:value-of select="very-lo"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="bitmap">
    <img src="{.}" align="left"/>
  </xsl:template>

  <xsl:template match="image">
    <DIV>
      <tr>
        <td>
          <img src="{./bitmap}" align="left" border="1"/>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:apply-templates select="file"/>
          <p></p>
        </td>
      </tr>
    </DIV>
  </xsl:template>

  <xsl:template match="report-conclusion">
    <DIV>
      <xsl:apply-templates select="text"/>
      <xsl:apply-templates select="file"/>
    </DIV>
  </xsl:template>

  </xsl:stylesheet>
